@@ -24,16 +24,22 @@ class Finder:
         resolve_symlinks: bool = False,
         no_same_file: bool = False,
         no_same_interpreter: bool = False,
+        selected_providers: list[str] | None = None,
     ) -> None:
         self.resolve_symlinks = resolve_symlinks
         self.no_same_file = no_same_file
         self.no_same_interpreter = no_same_interpreter
+        self._providers = self.setup_providers(selected_providers)
 
-        self._providers = self.setup_providers()
-
-    def setup_providers(self) -> list[BaseProvider]:
+    def setup_providers(
+        self,
+        selected_providers: list[str] | None = None,
+    ) -> list[BaseProvider]:
         providers: list[BaseProvider] = []
-        for provider_class in ALL_PROVIDERS:
+        allowed_providers = ALL_PROVIDERS
+        if selected_providers is not None:
+            allowed_providers = {name: ALL_PROVIDERS[name] for name in selected_providers}
+        for provider_class in allowed_providers.values():
             provider = provider_class.create()
             if provider is None:
                 logger.debug("Provider %s is not available", provider_class.__name__)
@@ -70,6 +76,7 @@ class Finder:
         :param dev: Whether the python is a devrelease.
         :param name: The name of the python.
         :param architecture: The architecture of the python.
+        :param from_provider: Providers to use (default: use all).
         :return: a list of PythonVersion objects
         """
         if isinstance(major, str):
@@ -123,6 +130,7 @@ class Finder:
         :param dev: Whether the python is a devrelease.
         :param name: The name of the python.
         :param architecture: The architecture of the python.
+        :param from_provider: Providers to use (default: use all).
         :return: a Python object or None
         """
         return next(
@@ -149,7 +157,7 @@ class Finder:
                 return python_version.real_path.as_posix()
             return python_version.executable.as_posix()
 
-        def sort_key(python_version: PythonVersion) -> tuple[int, int]:
+        def sort_key(python_version: PythonVersion) -> tuple[int, int, int]:
             return (
                 python_version.executable.is_symlink(),
                 get_suffix_preference(python_version.name),
