@@ -9,7 +9,7 @@ from findpython.python import PythonVersion
 
 class _MockRegistry:
     def __init__(self) -> None:
-        self.versions = {}
+        self.versions: dict[Path, PythonVersion] = {}
 
     def add_python(
         self,
@@ -51,7 +51,8 @@ def mocked_python(tmp_path, monkeypatch):
     monkeypatch.setattr(
         "findpython.providers.base.BaseProvider.version_maker", mocked.version_maker
     )
-    ALL_PROVIDERS[:] = [PathProvider]
+    ALL_PROVIDERS.clear()
+    ALL_PROVIDERS["path"] = PathProvider
     monkeypatch.setenv("PATH", str(tmp_path))
     return mocked
 
